@@ -15,6 +15,7 @@ namespace net
 PacketSocket::PacketSocket(SocketDevice *sock)
     : TrafficShapedSocket(sock)
     , ctrl_packets_sent(0)
+    , pending_upload_data_bytes(0)
     , uploaded_data_bytes(0)
 {
 }
@@ -22,6 +23,7 @@ PacketSocket::PacketSocket(SocketDevice *sock)
 PacketSocket::PacketSocket(int fd, int ip_version)
     : TrafficShapedSocket(fd, ip_version)
     , ctrl_packets_sent(0)
+    , pending_upload_data_bytes(0)
     , uploaded_data_bytes(0)
 {
 }
@@ -29,6 +31,7 @@ PacketSocket::PacketSocket(int fd, int ip_version)
 PacketSocket::PacketSocket(bool tcp, int ip_version)
     : TrafficShapedSocket(tcp, ip_version)
     , ctrl_packets_sent(0)
+    , pending_upload_data_bytes(0)
     , uploaded_data_bytes(0)
 {
 }
@@ -82,6 +85,7 @@ Uint32 PacketSocket::write(Uint32 max, bt::TimeStamp now)
             QMutexLocker locker(&mutex);
             if (curr_packet->getType() == PIECE) {
                 up_speed->onData(ret, now);
+                pending_upload_data_bytes -= ret;
                 uploaded_data_bytes += ret;
             }
         } else
@@ -113,10 +117,12 @@ Uint32 PacketSocket::write(Uint32 max, bt::TimeStamp now)
 
 void PacketSocket::addPacket(Packet::Ptr packet)
 {
+    Q_ASSERT(!packet->sending());
     QMutexLocker locker(&mutex);
-    if (packet->getType() == PIECE)
+    if (packet->getType() == PIECE) {
         data_packets.push_back(packet);
-    else
+        pending_upload_data_bytes += packet->getDataLength();
+    } else
         control_packets.push_back(packet);
     // tell upload thread we have data ready should it be sleeping
     net::SocketMonitor::instance().signalPacketReady();
@@ -151,7 +157,7 @@ void PacketSocket::clearPieces(bool reject)
         if (p->getType() == bt::PIECE && !p->sending() && curr_packet != p) {
             if (reject)
                 addPacket(Packet::Ptr(p->makeRejectOfPiece()));
-
+            pending_upload_data_bytes -= p->getDataLength();
             i = data_packets.erase(i);
         } else {
             i++;
@@ -166,6 +172,7 @@ void PacketSocket::doNotSendPiece(const bt::Request &req, bool reject)
     while (i != data_packets.end()) {
         Packet::Ptr p = *i;
         if (p->isPiece(req) && !p->sending() && p != curr_packet) {
+            pending_upload_data_bytes -= p->getDataLength();
             i = data_packets.erase(i);
             if (reject) {
                 // queue a reject packet
@@ -183,4 +190,10 @@ Uint32 PacketSocket::numPendingPieceUploads() const
     return data_packets.size();
 }
 
+Uint32 PacketSocket::numPendingPieceUploadBytes() const
+{
+    QMutexLocker locker(&mutex);
+    return pending_upload_data_bytes;
+}
+
 }
