@@ -30,6 +30,13 @@ public:
     SHA1HashGen();
     ~SHA1HashGen();
 
+    /**
+     * Generate a hash from a bunch of data.
+     * @param data The data
+     * @return The SHA1 hash
+     */
+    SHA1Hash generate(QByteArrayView data);
+
     /**
      * Generate a hash from a bunch of data.
      * @param data The data
@@ -43,6 +50,12 @@ public:
      */
     void start();
 
+    /**
+     * Update the hash.
+     * @param data The data
+     */
+    void update(QByteArrayView data);
+
     /**
      * Update the hash.
      * @param data The data
